//===-- MachineFunctionPass.cpp - Pass for MachineFunctions ------*-C++ -*-===//
//
//                     The LLVM Compiler Infrastructure
//
// This file was developed by the LLVM research group and is distributed under
// the University of Illinois Open Source License. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//
//
// This file defines the MachineFunctionPass class.  MachineFunctionPass's are
// just FunctionPass's, except they operate on machine code as part of a code
// generator.  Because they operate on machine code, not the LLVM
// representation, MachineFunctionPass's are not allowed to modify the LLVM
// representation.  Due to this limitation, the MachineFunctionPass class takes
// care of declaring that no LLVM passes are invalidated.
//
//===----------------------------------------------------------------------===//

#include "llvm/CodeGen/MachineFunctionPass.h"
#include "llvm/CodeGen/MachineFunctionProvider.h"

namespace llvm {

void MachineFunctionPass::getAnalysisUsage(AnalysisUsage &AU) const {
  AU.addRequired<MachineFunctionProvider>();
  AU.addPreserved<MachineFunctionProvider>();
  // FIXME: This pass should declare that the pass does not invalidate any LLVM
  // passes.
  FunctionPass::getAnalysisUsage(AU);
}

bool MachineFunctionPass::runOnFunction(Function &F) {
  return runOnMachineFunction(getAnalysis<MachineFunctionProvider>().getMF());
}

} // End llvm namespace
