//===-- MachineFunctionProvider.h - Creates MachineFunctions -----*-C++ -*-===//
//
//                     The LLVM Compiler Infrastructure
//
// This file was developed by Gordon Henriksen and is distributed under the
// University of Illinois Open Source License. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//
//
// This file defines the MachineFunctionProvider class. This analysis provides
// access to a MachineFunction object.
//
//===----------------------------------------------------------------------===//

#include "llvm/CodeGen/MachineFunctionProvider.h"
#include "llvm/CodeGen/MachineFunction.h"
#include "llvm/Target/TargetLowering.h"

// FIXME <[!CDATA
#include <stdio.h>
#include <llvm/Function.h>
// ]> FIXME

namespace llvm {

static RegisterPass<MachineFunctionProvider>
X("prepare-machine-function", "Prepare Machine Function");

MachineFunctionProvider::MachineFunctionProvider()
  : CurrentFn(0), CurrentMF(0)
{}

void MachineFunctionProvider::getAnalysisUsage(AnalysisUsage &AU) const {
  AU.setPreservesAll();
}

bool MachineFunctionProvider::runOnFunction(Function &Fn) {
  CurrentFn = &Fn;
  return false;
}

MachineFunction &MachineFunctionProvider::makeMF(TargetMachine &TM) {
  assert(!CurrentMF && "MachineFunction already constructed");
  CurrentMF = new MachineFunction(CurrentFn, TM);
  return *CurrentMF;
}

MachineFunction & MachineFunctionProvider::getMF() const {
  assert(CurrentMF && "getMF called before makeMF, or "
                      "MachineFunctionProvider pass was invalidated");
  return *CurrentMF;
}

void MachineFunctionProvider::releaseMemory() {
  if (CurrentMF) {
    delete CurrentMF;
    CurrentMF = 0;
  }
  CurrentFn = 0;
}

MachineFunctionProvider::~MachineFunctionProvider() {
  releaseMemory();
}

MachineFunctionProvider *createMachineFunctionProvider() {
  return new MachineFunctionProvider();
}

} // End llvm namespace
